@@ -5,6 +5,7 @@
 $ jsmin_all.py $lp_js_root
 
 """
+import argparse
 import os
 import re
 import sys
@@ -47,13 +48,35 @@ def minify_stream(instream, outstream):
     jsm.minify(instream, outstream)
 
 
-def main():
-    root = sys.argv[1]
+def _parse_args():
+    """Process args with argparse"""
+    desc = """Minify Javascript.
 
-    if os.path.isfile(root):
-        minify(root)
+    You can either pass --path/-p or read from stdid
+    """
+
+    parser = argparse.ArgumentParser(description=desc)
+    parser.add_argument('--path', '-p', dest='path',
+                            action='store',
+                            default=None,
+                            required=False,
+                            help='Specify the path to minimize (directory or file)')
+    args = parser.parse_args()
+    return args
+
+def main():
+    args = _parse_args()
+
+    if args.path:
+        root = args.path
+
+        if os.path.isfile(root):
+            minify(root)
+        else:
+            [minify(f) for f in dirwalk(root)]
     else:
-        [minify(f) for f in dirwalk(root)]
+        jsm = JavascriptMinify()
+        jsm.minify(sys.stdin, sys.stdout)
 
 
 if __name__ == '__main__':
